@@ -1,6 +1,6 @@
 package Classic::Perl;
 
-my %features = map +($_ => undef)  =>=>  qw< split $* >;
+my %features = map +($_ => undef)  =>=>  qw< $[ split $* >;
 
 sub import{
  shift;
@@ -13,12 +13,16 @@ sub import{
   $_ eq '$*' and &_enable_multiline;
   next if $] < 5.0109999;
   $_ eq 'split' and $^H{Classic_Perl__split} = 1;
+  next if $] < 5.0150029;
+  $_ eq '$[' and $^H{'Classic_Perl__$['} = 0;
  }
  return if @_;
  return if $] < 5.0089999;
  &_enable_multiline;
  return if $] < 5.0109999;
  $^H{Classic_Perl__split} = 1;
+ return if $] < 5.0150029;
+ $^H{'Classic_Perl__$['} = 0;
  return;
 }
 sub _enable_multiline {
@@ -39,6 +43,10 @@ sub unimport {
   delete $^H{"Classic_Perl__$_"};
  }
  return if @_;
+ if($^H{'Classic_Perl__$['}) {
+  Array::Base->unimport;
+  String::Base->unimport;
+ }
  if(exists $^H{'Classic_Perl__$*'} and $] > 5.0130069 and $INC{"re.pm"}) {
   unimport re:: "/m";
  }
@@ -47,7 +55,7 @@ sub unimport {
 }
 
 BEGIN {
- $VERSION='0.02';
+ $VERSION='0.03';
  if($]>5.0089999){
   require XSLoader;
   XSLoader::load(__PACKAGE__, $VERSION);
@@ -62,6 +70,7 @@ sub VERSION {
  my @features;
  push @features, '$*'    if $_[1] < 5.0089999;
  push @features, 'split' if $_[1] < 5.0109999;
+ push @features, '$['    if $_[1] < 5.0150029;
  Classic::Perl->import(@features) if @features;
 }
 
@@ -73,10 +82,14 @@ Classic::Perl - Selectively reinstate deleted Perl features
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
+  use Classic::Perl '$[';
+  $[ = 1;
+  print qw(a b c d)[2]; # prints "b"
+
   use Classic::Perl;
   # or
   use Classic::Perl 'split';
@@ -120,15 +133,16 @@ lexically-scoped, so:
 To enable or disable a specific set of features, pass them as arguments to
 C<use> or C<no>:
 
-  use Classic::Perl qw< split $* >;
+  use Classic::Perl qw< $[ split $* >;
 
 To enable features that still existed in a given version of perl, put
 I<four> colons in your C<use> statement, followed by the perl version. Only
 plain numbers (C<5.008>) are currently supported. Don't use v-strings
 (C<v5.8.0>).
 
-  use Classic::::Perl 5.012; # does nothing (yet)
-  use Classic::::Perl 5.010; # enables split, but not $*
+  use Classic::::Perl 5.016; # does nothing (yet)
+  use Classic::::Perl 5.014; # enables $[, but not split or $*
+  use Classic::::Perl 5.010; # enables $[ and split, but not $*
   use Classic::::Perl 5.008; # enables everything
 
 This is not guaranteed to do anything reasonable if used with C<no>.
@@ -137,6 +151,21 @@ This is not guaranteed to do anything reasonable if used with C<no>.
 
 =over
 
+=item $[
+
+This feature provides the C<$[> variable, which, when set to an integer
+other than zero, offsets indices into arrays and strings.  For example,
+setting it to 1 (almost the only non-zero value actually used) means
+that the first element in an array has index 1 rather than the usual 0.
+The index offset is lexically scoped, as C<$[> was in Perl 5.0-5.14,
+unlike its behaviour in Perl 1-4.
+
+Some details of the index offsetting behaviour differ from C<$[>'s
+historical behaviour.  See L<Array::Base> and L<String::Base>, which
+provide the new semantics, for details.
+
+This is due to be removed from perl in 5.15.
+
 =item split
 
 This features provides C<split> to C<@_> in void and scalar context.
@@ -174,9 +203,11 @@ autobox, which filched it from perl. :-)
 
 L<perl> 5 or higher
 
+In Perl 5.16 and higher, L<Array::Base> and L<String::Base> are required.
+
 =head1 COPYRIGHT
 
-Copyright (C) 2010 Father Chrysostomos
+Copyright (C) 2010-11 Father Chrysostomos
 
   use Classic'Perl;
   split / /, 'org . cpan @ sprout';
@@ -187,8 +218,10 @@ under the same terms as perl.
 
 =head1 SEE ALSO
 
-L<perl>, L<C<split> in perlfunc|perlfunc/split>, C<UNIVERSAL>,
-C<C<$*> in perlvar|perlvar/$*>
+L<Array::Base>, L<String:Base>,
+L<perl>, L<C<split> in perlfunc|perlfunc/split>,
+L<C<$*> in perlvar|perlvar/$*>,
+C<C<$[> in perlvar|perlvar/$[>
 
 L<any::feature> is an experimental module that backports new Perl features
 to older versions.
